package gov.michigan.msp.micrmidexmessages.clientsample;



import java.io.File;
import java.util.Iterator;

import javax.activation.DataHandler;
import javax.activation.FileDataSource;
import javax.activation.MimetypesFileTypeMap;
import javax.xml.soap.AttachmentPart;
import javax.xml.soap.MessageFactory;
import javax.xml.soap.Name;
import javax.xml.soap.SOAPBody;
import javax.xml.soap.SOAPBodyElement;
import javax.xml.soap.SOAPConnection;
import javax.xml.soap.SOAPConnectionFactory;
import javax.xml.soap.SOAPElement;
import javax.xml.soap.SOAPEnvelope;
import javax.xml.soap.SOAPMessage;
import javax.xml.soap.SOAPPart;
import org.springframework.ws.soap.saaj.SaajSoapMessageFactory;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import gov.michigan.msp.micrmidexmessages.MicrMidexRequestType;

public class MicrXmlWSRequestUtil {
	/**
	 * Logger for this class
	 */
	private SaajSoapMessageFactory saajMessageFactory;
	private static final String NAMESPACE_URI = "http://www.michigan.gov/msp/micrmidexmessages";
	private static final String NAMESPACE_PREFIX = "mic";
	private static final String AUTH_NS = "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd";
	private static final String AUTH_PREFIX="wsse";
	private static final String AUTH_WSU_NS = "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd";
	private static final String AUTH_WSU_PREFIX="xmlns:wsu";

	public void setSaajMessageFactory(SaajSoapMessageFactory saajMessageFactory) {
		this.saajMessageFactory = saajMessageFactory;
	}

	public SaajSoapMessageFactory getSaajMessageFactory() {
		return saajMessageFactory;
	}

	public boolean sendToMicrMidesWs (File xmlFile, File xsltFile, boolean isMicrSubmission,
			boolean isNdexSubmission, String environment, String clientId, String accessToken) throws Exception {
		this.saajMessageFactory = new SaajSoapMessageFactory();
		FileDataSource xmlfileDataSource = null;
		DataHandler xmlDataHandler = null;
		String status = null;
		String detail = null;
		String systemMessages = null;
		boolean isError = false;
		Name childName;
		MessageFactory messageFactory = MessageFactory.newInstance();
		saajMessageFactory.setMessageFactory(messageFactory );
		SOAPMessage message = saajMessageFactory.getMessageFactory().createMessage();
		SOAPElement wsSecHeaderElm = message.getSOAPHeader().addChildElement("Security",AUTH_PREFIX,AUTH_NS);
		wsSecHeaderElm.setAttribute(AUTH_WSU_PREFIX,AUTH_WSU_NS);
		SOAPElement userNameTokenElm = message.getSOAPHeader().addChildElement("UsernameToken",AUTH_PREFIX,AUTH_NS);
		userNameTokenElm.setAttribute("wsu:Id", "UsernameToken-10");

		SOAPElement userNameElm = message.getSOAPHeader().addChildElement("Username",AUTH_PREFIX,AUTH_NS);
		userNameElm.addTextNode(clientId);

		SOAPElement passwdElm = message.getSOAPHeader().addChildElement("Password",AUTH_PREFIX,AUTH_NS);
		passwdElm.setAttribute("Type", "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-username-token-profile-1.0#PasswordText");
		passwdElm.addTextNode(accessToken);
		userNameTokenElm.addChildElement(userNameElm);
		userNameTokenElm.addChildElement(passwdElm);

		SOAPPart SOAPPart = message.getSOAPPart();
		SOAPEnvelope envelope = SOAPPart.getEnvelope();

		wsSecHeaderElm.addChildElement(userNameTokenElm);
		message.getSOAPHeader().addChildElement(wsSecHeaderElm);
		envelope.addNamespaceDeclaration(NAMESPACE_PREFIX, NAMESPACE_URI);
		SOAPBody body = envelope.getBody();
		MimetypesFileTypeMap map = null;
		MicrMidexRequestType micrMidexRequestType = new MicrMidexRequestType();
		micrMidexRequestType.setMicrSubmissionIndicator(isMicrSubmission);
		micrMidexRequestType.setNdexSubmissionIndicator(isNdexSubmission);

		Name bodyName = envelope.createName("MicrMidexRequest", NAMESPACE_PREFIX, NAMESPACE_URI);
		SOAPBodyElement micrRequest = body.addBodyElement(bodyName);

		childName = envelope.createName("MicrSubmissionIndicator", NAMESPACE_PREFIX, NAMESPACE_URI);

		SOAPElement micrSubmissionIndicatorElement = micrRequest.addChildElement(childName);
		micrSubmissionIndicatorElement.addTextNode("true");


		childName = envelope.createName("NdexSubmissionIndicator", NAMESPACE_PREFIX, NAMESPACE_URI);

		SOAPElement ndexSubmissionIndicatorElement = micrRequest.addChildElement(childName);
		ndexSubmissionIndicatorElement.addTextNode("false");


		SOAPElement bodyElement = body.addChildElement(micrRequest);

		//Set the MIME Type
		map = new MimetypesFileTypeMap();
		map.addMimeTypes("text/xml");

		if (xmlFile != null){
			xmlfileDataSource = new FileDataSource(xmlFile);
			xmlfileDataSource.setFileTypeMap(map);
			xmlDataHandler = new DataHandler(xmlfileDataSource);
		}

		//Add xml attachment
		if (xmlDataHandler != null){
			AttachmentPart xmlAttachment = message.createAttachmentPart(xmlDataHandler);
			xmlAttachment.setContentId("micrmidexdata");
			xmlAttachment.setContentType("text/xml");
			message.addAttachmentPart(xmlAttachment);
		}
		message.saveChanges();

		String destination = "https://eapps.msp.state.mi.us/MICRMIDEXWS/TEST/micrmidexws";

		SOAPConnectionFactory factory = SOAPConnectionFactory.newInstance();
		SOAPConnection connection = factory.createConnection();
		SOAPMessage result = connection.call(message,destination);

		SOAPPart responsePart = result.getSOAPPart();
		SOAPEnvelope responseEnvelope = responsePart.getEnvelope();
		SOAPBody responseBody = responseEnvelope.getBody();
		if(null != responseBody.getFault()) {
			systemMessages = responseBody.getFault().getFaultString();
			status = "FAILURE";
		}
		NodeList micrResponseList = responseBody.getElementsByTagName("MicrResponse");
		for (int count = 0; count < micrResponseList.getLength(); count++) {
			Node micrResponseNode = micrResponseList.item(count);
			if (micrResponseNode.getNodeType() == Node.ELEMENT_NODE) {
				Element micrResponseElement = (Element) micrResponseNode;
				try {
					status = micrResponseElement.getElementsByTagName("Status").item(0).getTextContent();
				} catch (Exception donothing) {}
			}
		}
		Iterator<?> iterator = result.getAttachments();
		if(iterator.hasNext()) {
			isError = true;
		}
		if(!isError && status.equalsIgnoreCase("FAILURE")) {
			isError = true;
		}
		connection.close();
		return isError;
	}
}
