using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Net.Http;
using System.Net;
using System.IO;

namespace MICRWebService
{
    
   public class MICRSUBMISSION
    {
       private string BOUNDARY_DEF = "=_Part_" + DateTime.Now.Ticks.ToString("x");
      
       
       public string MICRContentType {
           get 
               {
                   return "multipart/related;type=\"text/xml\";charset=UTF-8;boundary=\"" + this.BOUNDARY_DEF + "\"";
               }
       }

       public bool MicrSubmissionIndicator { get; set; }
       public bool NdexSubmissionIndicator { get; set; }
       public string MICR_URL { get; set; }
       public string UserName { get; set; }
       public string Password { get; set; }
       public string XMLFilePath {get; set;}
       public string  MICRResponse { get; set; }

       public  string ProcessMICRTransaction()
       {


           try
           {
               // check for the required parameters.
               if ( this.MICR_URL =="" || this.MICR_URL ==null)
               {
                   return "Please enter the correct URL";
               }
               //check for the required User Name.
               if (this.UserName == "" || this.UserName == null)
               {
                   return "Please enter the correct UserName";
               }
               // check for the required password.
               if (this.Password == "" || this.Password == null)
               {
                   return "Please enter the correct Password";
               }
                // check for the required XML file path.
                // this will not verify weather the file exists or not
               if (this.XMLFilePath == "" || this.XMLFilePath == null)
               {
                   return "Please enter the correct path of the xml file";
               }

               //Creating the MICR Request based on the URL
               HttpWebRequest wr = (HttpWebRequest)WebRequest.Create(this.MICR_URL);
               wr.Method = "POST";  //Setting the type of the HTTP Web Request
               wr.KeepAlive = true;
               wr.ContentType = this.MICRContentType;
               Stream rs = wr.GetRequestStream();

               //Creating the body header
               string bodyHeader = "\r\n" + "\r\n" + "--" + this.BOUNDARY_DEF + "\r\n" + "Content-Type: text/xml; charset=UTF-8" + "\r\n" + "Content-Transfer-Encoding: 8bit" + "\r\n" + "Content-ID: <rootpart@soapui.org>" + "\r\n\r\n\r\n";
               byte[] bytesHeader = System.Text.Encoding.UTF8.GetBytes(bodyHeader);
               //Sending the body Header
               rs.Write(bytesHeader, 0, bytesHeader.Length);

               // 'Creating the body header
               // '"--" should be injected to the boundary definition
               string strRequestBody = "<soapenv:Envelope xmlns:mic=\"http://www.michigan.gov/msp/micrmidexmessages\" xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">\r\n<soapenv:Header><wsse:Security soapenv:mustUnderstand=\"1\" xmlns:wsse=\"http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd\" xmlns:wsu=\"http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd\"><wsse:UsernameToken wsu:Id=\"UsernameToken-1E5525AC524632E089144734286406971\"><wsse:Username>YOUR_USERNAME</wsse:Username><wsse:Password Type=\"http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-username-token-profile-1.0#PasswordText\">YOUR_PASSWORD</wsse:Password><wsse:Nonce EncodingType=\"http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-soap-message-security-1.0#Base64Binary\">OVXwnkMlmkeBY/OEZX1/yw==</wsse:Nonce><wsu:Created>2015-11-12T15:41:04.069Z</wsu:Created></wsse:UsernameToken></wsse:Security></soapenv:Header>\r\n<soapenv:Body>\r\n<mic:MicrMidexRequest>\r\n<mic:MicrSubmissionIndicator>" + this.MicrSubmissionIndicator + "</mic:MicrSubmissionIndicator>\r\n<mic:NdexSubmissionIndicator>" + this.NdexSubmissionIndicator + "</mic:NdexSubmissionIndicator>\r\n</mic:MicrMidexRequest>\r\n</soapenv:Body>\r\n</soapenv:Envelope>\r\n";
               //Sending the soap Header
               byte[] bytesRequestBody = System.Text.Encoding.UTF8.GetBytes(strRequestBody);
               rs.Write(bytesRequestBody, 0, bytesRequestBody.Length);


               //Creating header for the xml attachment 
               string strXMLHeaderFile = "--" + this.BOUNDARY_DEF + "\r\n" + "Content-Type: text/xml;charset=Cp1252;name=myfile.xml" + "\r\nContent-Transfer-Encoding:7bit \r\nContent-ID: <micrmidexdata> \r\nContent-Disposition: attachment; name=\"myfile.xml\"; filename=\"myfile.xml\" \r\n\r\n";
               byte[] headerbytes = System.Text.Encoding.UTF8.GetBytes(strXMLHeaderFile);
               rs.Write(headerbytes, 0, headerbytes.Length);


               // Attaching the file.
               FileStream fileStream = new FileStream(this.XMLFilePath, FileMode.Open, FileAccess.Read);
               byte[] buffer = new byte[4096];
               int bytesRead = 0;
               while ((bytesRead = fileStream.Read(buffer, 0, buffer.Length)) != 0)
               {
                   rs.Write(buffer, 0, bytesRead);
               }
               //Closing the file stream.
               fileStream.Close();
               byte[] trailer = System.Text.Encoding.ASCII.GetBytes("\r\n--" + this.BOUNDARY_DEF + "--\r\n");
               rs.Write(trailer, 0, trailer.Length);

               // getting the response back.
               WebResponse wresp = null;
               try
               {
                   wresp = wr.GetResponse();
                   Stream StreamMICRResponse = wresp.GetResponseStream();
                   StreamReader reader = new StreamReader(StreamMICRResponse);
                   this.MICRResponse = reader.ReadToEnd(); // Saving the response to the string

               }
               catch (Exception ex)
               {
                   return ex.Message;
                   if (wresp != null)
                   {
                       wresp.Close();
                       wresp = null;
                   }
               }
               finally
               {
                   wr = null;
               }
           }
           catch (Exception ex)
           {
               return ex.Message;
           }

           return this.MICRResponse;

       }


    }
}
