<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:nc="http://niem.gov/niem/niem-core/2.0"
                xmlns:lexs="http://usdoj.gov/leisp/lexs/3.1"
                xmlns:lexsdigest="http://usdoj.gov/leisp/lexs/digest/3.1"
                xmlns:ndexia="http://fbi.gov/cjis/N-DEx/IncidentArrest/2.1"
                xmlns:lexslib="http://usdoj.gov/leisp/lexs/library/3.1"
                xmlns:s="http://niem.gov/niem/structures/2.0"
                xmlns:fn="http://www.w3.org/2005/xpath-functions"
                xmlns:lexspd="http://usdoj.gov/leisp/lexs/publishdiscover/3.1"
                xmlns:j="http://niem.gov/niem/domains/jxdm/4.0"
                xmlns:mspRoot="http://www.michigan.gov/msp/IncidentReporting/exchange/1.0"
                xmlns:msp="http://www.michigan.gov/msp/IncidentReporting/extensions/1.0"
                xmlns:mspfx="http://www.michigan.gov/msp/IncidentReporting"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
<xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


<!--PROLOG-->
<xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


<!--KEYS AND FUNCTIONS-->
<xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-message"
                 as="xs:string">
        <xsl:param name="errorNumberIN" as="xs:string"/>
        
        <xsl:sequence select="concat(concat($micr_edits_lookup//ROW/COLUMN[@NAME = 'ERROR_NUMBER' and text() = $errorNumberIN]/../COLUMN[@NAME = 'EDIT_NUMBER']/text(),': '),$micr_edits_lookup//ROW/COLUMN[@NAME = 'ERROR_NUMBER' and text() = $errorNumberIN]/../COLUMN[@NAME = 'MESSAGE_DESCRIPTION']/text())"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-prefixed-message"
                 as="xs:string">
        <xsl:param name="errorNumberIN" as="xs:string"/>
        <xsl:param name="prefixIN" as="xs:string*"/>
        <xsl:param name="prefixNumberIN" as="xs:string*"/>
        
        <xsl:sequence select="concat(concat($prefixIN,concat(' ',concat($prefixNumberIN,' '))),mspfx:error-message($errorNumberIN))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-315"
                 as="xs:boolean">
        
        <xsl:sequence select="boolean(mspfx:no-offender-number-exists() and not($isZeroRec))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-731"
                 as="xs:boolean">
        <xsl:param name="arrestNumberIN" as="xs:string"/>
        <xsl:param name="offenderNumberIN" as="xs:string"/>
        
        <xsl:sequence select="not($arrestNumberIN = $offenderNumberIN)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-1031"
                 as="xs:boolean">
        <xsl:param name="activityCategoryText" as="xs:string"/>
        
        <xsl:sequence select="boolean($activityCategoryText=('Offense','Incident','Arrest'))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:no-offender-number-exists"
                 as="xs:boolean">
        
        <xsl:sequence select="boolean(count(distinct-values($offenderNumbers)) = 0)"/>
    </xsl:function>

   <!--DEFAULT RULES-->


<!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
<!--This mode can be used to generate prefixed XPath for humans-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
<!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
<xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
<xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters--><xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
<xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl" title="" schemaVersion="">
         <xsl:attribute name="phase">delete-edits-only</xsl:attribute>
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="http://purl.oclc.org/dsdl/schematron" prefix="iso"/>
         <svrl:ns-prefix-in-attribute-values uri="http://niem.gov/niem/niem-core/2.0" prefix="nc"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/1999/XSL/Transform" prefix="xsl"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema" prefix="xsd"/>
         <svrl:ns-prefix-in-attribute-values uri="http://usdoj.gov/leisp/lexs/3.1" prefix="lexs"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema" prefix="xs"/>
         <svrl:ns-prefix-in-attribute-values uri="http://usdoj.gov/leisp/lexs/digest/3.1" prefix="lexsdigest"/>
         <svrl:ns-prefix-in-attribute-values uri="http://fbi.gov/cjis/N-DEx/IncidentArrest/2.1" prefix="ndexia"/>
         <svrl:ns-prefix-in-attribute-values uri="http://usdoj.gov/leisp/lexs/library/3.1" prefix="lexslib"/>
         <svrl:ns-prefix-in-attribute-values uri="http://niem.gov/niem/structures/2.0" prefix="s"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2005/xpath-functions" prefix="fn"/>
         <svrl:ns-prefix-in-attribute-values uri="http://usdoj.gov/leisp/lexs/publishdiscover/3.1" prefix="lexspd"/>
         <svrl:ns-prefix-in-attribute-values uri="http://niem.gov/niem/domains/jxdm/4.0" prefix="j"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.michigan.gov/msp/IncidentReporting/exchange/1.0"
                                             prefix="mspRoot"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.michigan.gov/msp/IncidentReporting/extensions/1.0"
                                             prefix="msp"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.michigan.gov/msp/IncidentReporting" prefix="mspfx"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">incident-details</xsl:attribute>
            <xsl:attribute name="name">incident-details</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M82"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">admin-data-constraints</xsl:attribute>
            <xsl:attribute name="name">admin-data-constraints</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M84"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->
<xsl:param name="fbi_codes" select="document('./schema/xsd/niem/fbi/2.0/fbi.xsd')"/>
   <xsl:param name="msp_codes" select="document('./schema/xsd/msp/MSP_Codes.xsd')"/>
   <xsl:param name="ori_codes"
              select="document('./schema/xsd/msp/MICR_ORI_Codes.xsd')"/>
   <xsl:param name="ndexia_codes"
              select="document('./schema/xsd/ndexia/ndexia-codes/2.1/ndexia-codes.xsd')"/>
   <xsl:param name="ctxrf_lookup" select="document('./tables/CTXRF.xml')"/>
   <xsl:param name="orict_lookup" select="document('./tables/ORICT.xml')"/>
   <xsl:param name="filec_lookup" select="document('./tables/FILEC.xml')"/>
   <xsl:param name="val_lookup"
              select="document('./tables/SCHEMATRON_VALIDATION_LOOKUP.xml')"/>
   <xsl:param name="arrcd_lookup" select="document('./tables/ARRCD.xml')"/>
   <xsl:param name="ethinicity_lookup" select="document('./tables/ETHNICITY.xml')"/>
   <xsl:param name="residence_lookup" select="document('./tables/RESIDENCE.xml')"/>
   <xsl:param name="weapon_lookup" select="document('./tables/WEAPON.xml')"/>
   <xsl:param name="offenseactivity_lookup"
              select="document('./tables/OFFENSEACTIVITY.xml')"/>
   <xsl:param name="bias_lookup" select="document('./tables/BIAS.xml')"/>
   <xsl:param name="location_lookup" select="document('./tables/LOCATION.xml')"/>
   <xsl:param name="propertyloss_lookup"
              select="document('./tables/PROPERTYLOSS.xml')"/>
   <xsl:param name="propertyclass_lookup"
              select="document('./tables/PROPERTYCLASS.xml')"/>
   <xsl:param name="drug_lookup" select="document('./tables/DRUG.xml')"/>
   <xsl:param name="vor_lookup" select="document('./tables/VOR.xml')"/>
   <xsl:param name="injury_lookup" select="document('./tables/INJURY.xml')"/>
   <xsl:param name="micr_edits_lookup"
              select="document('./tables/MICR_EDITS_LKP.xml')"/>
   <xsl:param name="action"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:ActionCode"/>
   <xsl:param name="arrestExists"
              select="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:ArrestSubject/nc:RoleOfPersonReference)"/>
   <xsl:param name="assistOriId"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/nc:Organization[@s:id = //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:AssistingOrganization/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
   <xsl:param name="incidentDate"
              select="substring(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/*[text()] | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/*[text()and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/*[text()])] ,1,10)"/>
   <xsl:param name="incidentDateTime"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text() | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime[text() and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text())]"/>
   <xsl:param name="isActionOR" select="$action = 'O' or $action = 'R'"/>
   <xsl:param name="isExClear"
              select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident/j:IncidentAugmentation/j:IncidentExceptionalClearanceCode/text())"/>
   <xsl:param name="occurDate"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate[nc:DateTime | nc:Date]/text()"/>
   <xsl:param name="offenderExists"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Subject/nc:RoleOfOrganizationReference"/>
   <xsl:param name="offenderExist"
              select="boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Subject/nc:RoleOfOrganizationReference)"/>
   <xsl:param name="offenseExists"
              select="exists(//lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText = 'Offense'])"/>
   <xsl:param name="offenseCount"
              select="count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Offense'])"/>
   <xsl:param name="ori"
              select="//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI"/>
   <xsl:param name="victcomimCount"
              select="count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Victim)"/>
   <xsl:param name="victimExist"
              select="boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Victim)"/>
   <xsl:param name="victimExists"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim/nc:RoleOfPersonReference or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Victim/nc:RoleOfOrganizationReference"/>
   <xsl:param name="propertyClass"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyCategoryCode"/>
   <xsl:param name="propertyExist"
              select="boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug)"/>
   <xsl:param name="propertyExists"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property/nc:RoleOfItemReference or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Property/nc:RoleOfItemReference"/>
   <xsl:param name="propertyLoss"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyLossCode"/>
   <xsl:param name="offenderCount"
              select="count((//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference, //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Subject/nc:RoleOfOrganizationReference))"/>
   <xsl:param name="offenders"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference"/>
   <xsl:param name="arrestClearanceTrueCount"
              select="count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation[ndexia:ArresteeClearanceIndicator=true()])"/>
   <xsl:param name="offenseFileClasses"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode"/>
   <xsl:param name="propertyCount"
              select="count((//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property, //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug))"/>
   <xsl:param name="offenses"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode"/>
   <xsl:param name="completeOffenses"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref[../../../ndexia:OffenseCompletedIndicator = true()]]"/>
   <xsl:param name="attemptOffenses"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref[../../../ndexia:OffenseCompletedIndicator = false()]]"/>
   <xsl:param name="completeReqProp"
              select="$completeOffenses = ($filec_lookup//ROW[COLUMN/@NAME = 'PROP_REQUIRED' and COLUMN/text() = 'Y']/COLUMN[@NAME = 'FILEC_OFFENSE_CO']/text())"/>
   <xsl:param name="attemptReqProp"
              select="$attemptOffenses = ($val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 162]/COLUMN[@NAME = 'CODE']/text(), 39000 to 39009)"/>
   <xsl:param name="lossTypeList"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyLossCode/text()"/>
   <xsl:param name="duplicateOffender"
              select="count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText) != count(distinct-values(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText))"/>
   <xsl:param name="incidentNumber"
              select="//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID/text()"/>
   <xsl:param name="isZeroRec"
              select="$incidentNumber castable as xs:integer and number($incidentNumber) = 0"/>
   <xsl:param name="incidentComplete"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident/msp:IncidentCompleteIndicator"/>
   <xsl:param name="offenderNumbers"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText/number(text())"/>

   <!--PATTERN incident-details-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage" priority="1000" mode="M82">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage"/>
      <xsl:variable name="incidentNumber"
                    select="./lexs:Digest/lexsdigest:EntityActivity/nc:Activity/nc:ActivityIdentification/nc:IdentificationID"/>

		    <!--REPORT info-->
<xsl:if test="$ori">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$ori">
            <xsl:attribute name="id">ori</xsl:attribute>
            <xsl:attribute name="role">info</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="$ori"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT info-->
<xsl:if test="exists($incidentNumber/text()) and $incidentNumber/text() castable as xs:integer">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($incidentNumber/text()) and $incidentNumber/text() castable as xs:integer">
            <xsl:attribute name="id">incident-number</xsl:attribute>
            <xsl:attribute name="role">info</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="format-number($incidentNumber,'0000000000')"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT info-->
<xsl:if test="$action">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$action">
            <xsl:attribute name="id">action</xsl:attribute>
            <xsl:attribute name="role">info</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="$action"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT info-->
<xsl:if test="$incidentDate">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$incidentDate">
            <xsl:attribute name="id">orig-year</xsl:attribute>
            <xsl:attribute name="role">info</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="format-date(xs:date($incidentDate),'[Y0001]')"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M82"/>
   <xsl:template match="@*|node()" priority="-2" mode="M82">
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

   <!--PATTERN admin-data-constraints-->


	<!--RULE -->
<xsl:template match="//msp:ActionCode" priority="1008" mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl" context="//msp:ActionCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$msp_codes//xsd:simpleType[@name='ActionCodeSimpleType']//xsd:enumeration/@value = ."/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$msp_codes//xsd:simpleType[@name='ActionCodeSimpleType']//xsd:enumeration/@value = .">
               <xsl:attribute name="id">175</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>175: ACTION MUST BE O/R/D</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="$isZeroRec and not(text() = 'O') and $isActionOR">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$isZeroRec and not(text() = 'O') and $isActionOR">
            <xsl:attribute name="id">117</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>117: ACTION MUST BE O</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI"
                 priority="1007"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI"/>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID"
                 priority="1006"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="text() castable as xs:integer and number(text()) &gt;= 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="text() castable as xs:integer and number(text()) &gt;= 0">
               <xsl:attribute name="id">177_1</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>177: INCIDENT NUMBER MUST BE NUMERIC</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(text()) &lt;= 10"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string-length(text()) &lt;= 10">
               <xsl:attribute name="id">177_2</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>177:
			INCIDENT NUMBER MUST 10 CHARACTER OR LESS</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(.) = 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(.) = 1">
               <xsl:attribute name="id">177_3</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>177: SUBMISSION
			SHOULD ONLY CONTAIN ONE INCIDENT NUMBER</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(text())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(text())">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>111: INCIDENT NUMBER
			REQUIRED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//msp:LocationCountyCode" priority="1005" mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//msp:LocationCountyCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not($isActionOR) or empty(.) or distinct-values($ctxrf_lookup//ROW/COLUMN[@NAME = 'CTXRF_COUNTY']/text()) = number(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($isActionOR) or empty(.) or distinct-values($ctxrf_lookup//ROW/COLUMN[@NAME = 'CTXRF_COUNTY']/text()) = number(.)">
               <xsl:attribute name="id">110</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>110: INVALID COUNTY NUMBER</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']"
                 priority="1004"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="empty($incidentDateTime) or number(substring($incidentDateTime,12,2)) = (0 to 23,99)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($incidentDateTime) or number(substring($incidentDateTime,12,2)) = (0 to 23,99)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>138: HOUR-OCC MUST BE 00 TO 23 OR 99</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$incidentDate castable as xs:date"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$incidentDate castable as xs:date">
               <xsl:attribute name="id">113</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>113: INCIDENT DATE IS NOT VALID</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text()) &gt; 0 and $isZeroRec and $isActionOR">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text()) &gt; 0 and $isZeroRec and $isActionOR">
            <xsl:attribute name="id">121</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>121: REPORT DATE INDICATOR MUST BE R WITH ZERO RECORD
			ENTRY</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not((string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text()) &gt; 0 or string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:Date/text()) &gt; 0) or ( string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime/text()) &gt; 0 or string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:Date/text()) &gt; 0)) and $isActionOR">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not((string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text()) &gt; 0 or string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:Date/text()) &gt; 0) or ( string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime/text()) &gt; 0 or string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:Date/text()) &gt; 0)) and $isActionOR">
            <xsl:attribute name="id">122</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>122: REPORT DATE INDICATOR MUST BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$isActionOR and $isZeroRec and $incidentDate castable as xs:date and not(day-from-date(xs:date($incidentDate)) = 1)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$isActionOR and $isZeroRec and $incidentDate castable as xs:date and not(day-from-date(xs:date($incidentDate)) = 1)">
            <xsl:attribute name="id">120</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>120: DAY IN INCIDENT MUST BE 01</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate[nc:DateTime | nc:Date]/*[1]/text() | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate[nc:DateTime | nc:Date]/*[1][text() and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate[nc:DateTime | nc:Date]/*[1]/text())])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate[nc:DateTime | nc:Date]/*[1]/text() | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate[nc:DateTime | nc:Date]/*[1][text() and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate[nc:DateTime | nc:Date]/*[1]/text())])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>134: INCIDENT DATE IS REQUIRED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//j:IncidentExceptionalClearanceCode"
                 priority="1003"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//j:IncidentExceptionalClearanceCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not($isActionOR) or empty(text()) or $fbi_codes//xsd:simpleType[@name='IncidentExceptionalClearanceCodeSimpleType']//xsd:enumeration/@value = ."/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($isActionOR) or empty(text()) or $fbi_codes//xsd:simpleType[@name='IncidentExceptionalClearanceCodeSimpleType']//xsd:enumeration/@value = .">
               <xsl:attribute name="id">114</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>114: EXCEPTIONAL CLEARANCE MUST BE 10/11/12/13/14
		</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"
                 priority="1002"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"/>

		    <!--REPORT error-->
<xsl:if test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID) and not(some $x in //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimCategoryCode satisfies ($x = 'L'))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID) and not(some $x in //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimCategoryCode satisfies ($x = 'L'))">
            <xsl:attribute name="id">112</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>112: ASSIST ORI IS NOT A VALID FIELD</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"
                 priority="1001"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime | nc:Date or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/nc:DateTime | nc:Date) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime | nc:Date or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/nc:DateTime | nc:Date)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, DATE OF OCCURRENCE/REPORT IS
			MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(exists(//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI/text()))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(exists(//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, ORI IS MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(exists(//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID/text()))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(exists(//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, INCIDENT NUMBER IS MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/*[text()]) or exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/*[text()]))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/*[text()]) or exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/*[text()]))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, CANNOT DETERMINE ORIGINAL YEAR FROM
			ROPORT DATE OR ACTIVITY DATE</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(not($isActionOR) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress/msp:LocationCountyCode/text())) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(not($isActionOR) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress/msp:LocationCountyCode/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, COUNTY CODE IS MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(not($isActionOR) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress/msp:LocationCityTownshipCode/text()))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(not($isActionOR) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress/msp:LocationCityTownshipCode/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, CITY/TOWNSHIP CODE IS MISSING
		</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident/msp:IncidentCompleteIndicator)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident/msp:IncidentCompleteIndicator)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, INCIDENT COMPLETE INDICATOR MISSING
		</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident'])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, INCIDENT ENTITY ACTIVITY MISSING
		</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, NDEXIA:INCIDENT MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/nc:DateTime  or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/nc:DateTime or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, MISSING HOUR OCCURRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText"
                 priority="1000"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="mspfx:error-1031(./text())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="mspfx:error-1031(./text())">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="mspfx:error-message('1031')"/>
                  <xsl:text/>
		             </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M84"/>
   <xsl:template match="@*|node()" priority="-2" mode="M84">
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>
</xsl:stylesheet>
