<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:nc="http://niem.gov/niem/niem-core/2.0"
                xmlns:lexs="http://usdoj.gov/leisp/lexs/3.1"
                xmlns:lexsdigest="http://usdoj.gov/leisp/lexs/digest/3.1"
                xmlns:ndexia="http://fbi.gov/cjis/N-DEx/IncidentArrest/2.1"
                xmlns:lexslib="http://usdoj.gov/leisp/lexs/library/3.1"
                xmlns:s="http://niem.gov/niem/structures/2.0"
                xmlns:fn="http://www.w3.org/2005/xpath-functions"
                xmlns:lexspd="http://usdoj.gov/leisp/lexs/publishdiscover/3.1"
                xmlns:j="http://niem.gov/niem/domains/jxdm/4.0"
                xmlns:mspRoot="http://www.michigan.gov/msp/IncidentReporting/exchange/1.0"
                xmlns:msp="http://www.michigan.gov/msp/IncidentReporting/extensions/1.0"
                xmlns:mspfx="http://www.michigan.gov/msp/IncidentReporting"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
<xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


<!--PROLOG-->
<xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


<!--KEYS AND FUNCTIONS-->
<xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-message"
                 as="xs:string">
        <xsl:param name="errorNumberIN" as="xs:string"/>
        
        <xsl:sequence select="concat(concat($micr_edits_lookup//ROW/COLUMN[@NAME = 'ERROR_NUMBER' and text() = $errorNumberIN]/../COLUMN[@NAME = 'EDIT_NUMBER']/text(),': '),$micr_edits_lookup//ROW/COLUMN[@NAME = 'ERROR_NUMBER' and text() = $errorNumberIN]/../COLUMN[@NAME = 'MESSAGE_DESCRIPTION']/text())"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-prefixed-message"
                 as="xs:string">
        <xsl:param name="errorNumberIN" as="xs:string"/>
        <xsl:param name="prefixIN" as="xs:string*"/>
        <xsl:param name="prefixNumberIN" as="xs:string*"/>
        
        <xsl:sequence select="concat(concat($prefixIN,concat(' ',concat($prefixNumberIN,' '))),mspfx:error-message($errorNumberIN))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:warning-message"
                 as="xs:string">
        <xsl:param name="warningNumberIN" as="xs:string"/>
        
        <xsl:sequence select="concat('WARNING ',concat(concat($micr_edits_lookup//ROW/COLUMN[@NAME = 'ERROR_NUMBER' and text() = $warningNumberIN]/../COLUMN[@NAME = 'EDIT_NUMBER']/text(),': '),$micr_edits_lookup//ROW/COLUMN[@NAME = 'ERROR_NUMBER' and text() = $warningNumberIN]/../COLUMN[@NAME = 'MESSAGE_DESCRIPTION']/text()))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-110"
                 as="xs:boolean">
        <xsl:param name="oriIN" as="xs:string?"/>
        <xsl:param name="countyIN" as="xs:string?"/>        
        <xsl:param name="cityTwpIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean(mspfx:county-ori($oriIN,$countyIN) or mspfx:statewide-ori($oriIN) or mspfx:local-ori($oriIN,$countyIN,$cityTwpIN))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-911"
                 as="xs:boolean">
        <xsl:param name="currentLossType" as="xs:string?"/>
        
        <xsl:sequence select="boolean(not(mspfx:attempted-property-offense-with-zero-property-exists()) and mspfx:ofc-prop-loss-function-check('mspfx:error-911') and mspfx:prop-loss-error($currentLossType,'mspfx:error-911') and mspfx:prop-loss-ofcs($currentLossType))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-913"
                 as="xs:boolean">
        <xsl:param name="currentLossType" as="xs:string?"/>
        
        <xsl:sequence select="boolean(mspfx:ofc-prop-loss-function-check('mspfx:error-913') and mspfx:prop-loss-error($currentLossType,'mspfx:error-913') and mspfx:prop-loss-ofcs($currentLossType))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-914"
                 as="xs:boolean">
        <xsl:param name="currentLossType" as="xs:string?"/>
        
        <xsl:sequence select="boolean(mspfx:ofc-prop-loss-function-check('mspfx:error-914') and mspfx:prop-loss-error($currentLossType,'mspfx:error-914') and mspfx:prop-loss-ofcs($currentLossType))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-915"
                 as="xs:boolean">
        <xsl:param name="currentLossType" as="xs:string?"/>
        
        <xsl:sequence select="boolean(not(mspfx:attempted-property-offense-with-zero-property-exists()) and mspfx:ofc-prop-loss-function-check('mspfx:error-915') and mspfx:prop-loss-error($currentLossType,'mspfx:error-915') and mspfx:prop-loss-ofcs($currentLossType))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-916"
                 as="xs:boolean">
        <xsl:param name="currentLossType" as="xs:string?"/>
        
        <xsl:sequence select="boolean(not(mspfx:attempted-property-offense-with-zero-property-exists()) and mspfx:ofc-prop-loss-function-check('mspfx:error-916') and mspfx:prop-loss-error($currentLossType, 'mspfx:error-916') and mspfx:prop-loss-ofcs($currentLossType))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-917"
                 as="xs:boolean">
        <xsl:param name="currentLossType" as="xs:string?"/>
        
        <xsl:sequence select="boolean(mspfx:ofc-prop-loss-function-check('mspfx:error-917') and mspfx:prop-loss-error($currentLossType, 'mspfx:error-917') and mspfx:prop-loss-ofcs($currentLossType))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-OFC-PC-LT"
                 as="xs:boolean">
        <xsl:param name="currentPropertyClassIN" as="xs:string?"/>
        <xsl:param name="error" as="xs:string?"/>
        <xsl:param name="currentPropertyTypeIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean(mspfx:ofc-prop-class-function-check($error) and mspfx:all-ofc-prop-class-type($currentPropertyClassIN,$currentPropertyTypeIN))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-959"
                 as="xs:boolean">
        <xsl:param name="currentPropertyClassIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean(mspfx:ofc-prop-class-function-check('mspfx:error-959') and mspfx:all-ofc-prop-class($currentPropertyClassIN))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-960"
                 as="xs:boolean">
        <xsl:param name="currentPropertyClassIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean(mspfx:ofc-prop-class-function-check('mspfx:error-960') and mspfx:all-ofc-prop-class($currentPropertyClassIN))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-963"
                 as="xs:boolean">
        <xsl:param name="currentOffenseClassIN" as="xs:string?"/>
        <xsl:param name="offenseComplete" as="xs:boolean?"/>
        
        <xsl:sequence select="boolean(mspfx:ofc-prop-class-function-check-with-supplied-fclass('mspfx:error-963', $currentOffenseClassIN) and mspfx:all-ofc-prop-class-req($currentOffenseClassIN) and $offenseComplete)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-968"
                 as="xs:boolean">
        <xsl:param name="currentPropertyClassIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean(mspfx:ofc-prop-class-function-check('mspfx:error-968') and mspfx:all-ofc-prop-class($currentPropertyClassIN))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-970"
                 as="xs:boolean">
        <xsl:param name="currentPropertyClassIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean(mspfx:ofc-prop-class-function-check('mspfx:error-970') and mspfx:all-ofc-prop-class($currentPropertyClassIN))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-979"
                 as="xs:boolean">
        <xsl:param name="currentPropertyClassIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean(mspfx:ofc-prop-class-function-check('mspfx:error-979') and mspfx:all-ofc-prop-class($currentPropertyClassIN))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-973"
                 as="xs:boolean">
        <xsl:param name="currentOffenseClassIN" as="xs:string?"/>
        <xsl:param name="offenseComplete" as="xs:boolean?"/>
        
        <xsl:sequence select="boolean(mspfx:ofc-prop-class-function-check-with-supplied-fclass('mspfx:error-973', $currentOffenseClassIN) and mspfx:all-ofc-prop-class-req($currentOffenseClassIN) and $offenseComplete)"/>
        
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-732"
                 as="xs:boolean">
        <xsl:param name="arrestSubjectSid" as="xs:string?"/>
        <xsl:param name="offenderID" as="xs:string?"/>
        <xsl:param name="activityID" as="xs:string?"/>
        <xsl:param name="arrestNumber" as="xs:string?"/>
        <xsl:param name="arrestType" as="xs:string?"/>
        <xsl:param name="arrestAge" as="xs:string?"/>
        <xsl:param name="arrestRace" as="xs:string?"/>
        <xsl:param name="arrestSex" as="xs:string?"/>
        <xsl:param name="arrestCharge" as="xs:string?"/>
        <xsl:param name="arrestDate" as="xs:string?"/>
        
        <xsl:sequence select="mspfx:arrest-complete-check($arrestSubjectSid,$offenderID,$activityID,$arrestNumber,$arrestType,$arrestAge,$arrestRace,$arrestSex,$arrestCharge,$arrestDate)"/>
        
        </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-949"
                 as="xs:boolean">
        <xsl:param name="currentOffenseClassIN" as="xs:string*"/>
        <xsl:param name="drugCategoryCode" as="xs:string?"/>
        <xsl:param name="propertyClassIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean(mspfx:check-ofc-drug-cat($currentOffenseClassIN, $drugCategoryCode) or mspfx:check-drug-prop-class($drugCategoryCode, $propertyClassIN))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-974"
                 as="xs:boolean">
        <xsl:param name="currentOffenseClassIN" as="xs:string*"/>
        <xsl:param name="drugCategoryCode" as="xs:string*"/>
        <xsl:param name="drugMeasurement" as="xs:string*"/>
        <xsl:param name="lossType" as="xs:double*"/>
        <xsl:param name="propertyClassIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean(((not(exists($drugCategoryCode)) or mspfx:check-ofc-drug-cat($currentOffenseClassIN, $drugCategoryCode)) and exists($drugMeasurement)) or mspfx:check-drug-prop-class($drugCategoryCode, $propertyClassIN) or mspfx:check-drug-measure-exists($drugCategoryCode, $drugMeasurement, $lossType))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-975"
                 as="xs:boolean">
        <xsl:param name="currentOffenseClassIN" as="xs:string*"/>
        <xsl:param name="drugCategoryCode" as="xs:string*"/>
        <xsl:param name="drugQuantity" as="xs:string*"/>
        <xsl:param name="lossType" as="xs:double*"/>
        <xsl:param name="propertyClassIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean(((not(exists($drugCategoryCode)) or mspfx:check-ofc-drug-cat($currentOffenseClassIN, $drugCategoryCode)) and exists($drugQuantity)) or mspfx:check-drug-prop-class($drugCategoryCode, $propertyClassIN) or mspfx:check-drug-quantity-exists($drugCategoryCode, $drugQuantity, $lossType))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-315"
                 as="xs:boolean">
        
        <xsl:sequence select="boolean(mspfx:no-offender-number-exists() and not($isZeroRec))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-316"
                 as="xs:boolean">
        
        <xsl:sequence select="boolean(mspfx:offender-number-0-exists() and $offenderCount &gt;= 2)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-568"
                 as="xs:boolean">
        <xsl:param name="victimSubjectAssocCount" as="xs:double?"/>
        <xsl:param name="victimType" as="xs:string?"/>
        
        <xsl:sequence select="boolean(count($offenderNumbersNot0) &gt;= 2 and $victimSubjectAssocCount &lt; 2 and mspfx:victim-type-i-l($victimType))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-706"
                 as="xs:boolean">
        <xsl:param name="arrestAge" as="xs:string*"/>
        <xsl:param name="measurePointValue" as="xs:string*"/>
        <xsl:sequence select="boolean($arrestAge and (number($measurePointValue) &lt; 1 or number($measurePointValue) &gt; 99))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-713"
                 as="xs:boolean">
        <xsl:param name="arrestCharge" as="xs:string?"/>
        <xsl:param name="offenderArrestSubjectCount" as="xs:double?"/>
        
        <xsl:sequence select="boolean(mspfx:arresChargeGroup($arrestCharge) = 'A' and not(mspfx:ofcGroupAexist()) and $offenderArrestSubjectCount &gt; 0)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-958"
                 as="xs:boolean">
        <xsl:param name="drugCategoryCode" as="xs:string*"/>
        <xsl:param name="drugCount" as="xs:integer?"/>
        
        <xsl:sequence select="boolean(mspfx:drugType77NumDrugsCheck($drugCategoryCode,$drugCount))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-955"
                 as="xs:boolean">
        <xsl:param name="measure" as="xs:string*"/>
        <xsl:param name="quantity" as="xs:string*"/>
        <xsl:sequence select="boolean($measure = 'XX' and number($quantity) != 1000)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-907"
                 as="xs:boolean">
        <xsl:param name="offenses" as="xs:string*"/>
        <xsl:param name="drugType" as="xs:string?"/>
        <xsl:param name="lossType" as="xs:string?"/>
        <xsl:param name="drugSequence" as="xs:string?"/>
        <xsl:param name="otherDrugCnt" as="xs:integer?"/>
        <xsl:param name="otherFileClassCnt" as="xs:integer?"/>
        
        
        <xsl:sequence select="boolean(mspfx:checkDrugExists($offenses,$drugType, $lossType, $drugSequence, $otherDrugCnt, $otherFileClassCnt))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-977"
                 as="xs:boolean">
        <xsl:param name="countDrugCat99" as="xs:integer?"/>
        
        <xsl:sequence select="boolean(mspfx:checkDrugCat99($countDrugCat99))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-521"
                 as="xs:boolean">
    	<xsl:param name="victimType" as="xs:string?"/>
    	<xsl:param name="victimAge" as="xs:string?"/>
    	<xsl:param name="victimAgeUnit" as="xs:string?"/>
    	<xsl:param name="victimRole" as="xs:integer?"/>
    	<xsl:sequence select="mspfx:check-victim-type($victimType, '521')             and (($victimAgeUnit = 'ANN' and (mspfx:valid-range(number($victimAge),0,99) or string-length($victimAge) != 2))               or ($victimAgeUnit = 'DAY' and mspfx:valid-range(number($victimAge),1,364))               or ($victimAgeUnit = 'HUR' and mspfx:valid-range(number($victimAge),0,23)))              and $victimRole &gt; 0"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-599"
                 as="xs:boolean">
        <xsl:param name="vor" as="xs:boolean?"/>
        <xsl:param name="offenseCode" as="xs:string*"/>
        <xsl:param name="victimType" as="xs:string?"/>
        <xsl:param name="offenderNumbers" as="xs:string*"/>
        
        
        <xsl:sequence select="boolean(mspfx:victim-function-check-with-supplied-fclass('mspfx:error-599',$offenseCode) and mspfx:checkVorExists($vor, $offenseCode, $victimType, $offenderNumbers, ','))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-546"
                 as="xs:boolean">
        <xsl:param name="offenseCode" as="xs:string?"/>
        <xsl:param name="victimCircumstance" as="xs:string*"/>
        <xsl:param name="vicConnectedOffenseCodes" as="xs:string*"/>
        
        <xsl:sequence select="mspfx:offense-victimCircumstance-edit($offenseCode,'mspfx:error-546') and not(mspfx:offense-victimCircumstance($offenseCode,$victimCircumstance,$vicConnectedOffenseCodes))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-600"
                 as="xs:boolean">
        <xsl:param name="offenseCode" as="xs:string?"/>
        <xsl:param name="victimCircumstance" as="xs:string*"/>
        <xsl:param name="vicConnectedOffenseCodes" as="xs:string*"/>
        
        <xsl:sequence select="mspfx:offense-victimCircumstance-edit($offenseCode,'mspfx:error-600') and not(mspfx:offense-victimCircumstance($offenseCode,$victimCircumstance,$vicConnectedOffenseCodes))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-712"
                 as="xs:boolean">
        <xsl:param name="arrestCharge" as="xs:string?"/>
        <xsl:param name="offenderArrestSubjectCount" as="xs:double?"/>
        
        <xsl:sequence select="mspfx:check-arrestChargeCode($arrestCharge,$offenderArrestSubjectCount)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-165"
                 as="xs:boolean">
        <xsl:param name="biasCode" as="xs:string?"/>
        
        <xsl:sequence select="mspfx:check-biasCode($biasCode)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-525"
                 as="xs:boolean">
        <xsl:param name="victimType" as="xs:string?"/>
        <xsl:param name="victimAgeNode" as="xs:string?"/>
        <xsl:param name="victimAge" as="xs:double?"/>
        <xsl:param name="victimAgeMeasure" as="xs:string?"/>
        
        <xsl:sequence select="(mspfx:valid-range($victimAge,number(18),number(90)) and mspfx:victim-law-enforcement($victimType) and boolean($victimAgeNode) and mspfx:string-check($victimAgeMeasure,'ANN')) or (mspfx:victim-law-enforcement($victimType) and not(mspfx:string-check($victimAgeMeasure,'ANN')))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-212"
                 as="xs:boolean">
        
        <xsl:sequence select="boolean($propertyExist and mspfx:ofc-property-lkp('N'))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-905"
                 as="xs:boolean">
        
        <xsl:sequence select="boolean((mspfx:ofc-property-lkp-count('Y') = 1) and ($propertyCount &gt; 1) and ($zeroPropertyCount - $zeroDrugCount &gt; 0))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-961"
                 as="xs:boolean">
        <xsl:param name="itemNumberNode" as="xs:string?"/>
        
        <xsl:sequence select="boolean(not(exists($itemNumberNode)))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-943"
                 as="xs:boolean">
        <xsl:param name="numStlRecVeh" as="xs:string?"/>
        <xsl:param name="propertyClass" as="xs:string?"/>
        
        <xsl:sequence select="boolean(exists($numStlRecVeh) and number($numStlRecVeh) != 0 and not(exists(index-of(for $a in $micr_edits_ofc_prop_class_lookup//ROW[COLUMN[@NAME = 'STOLEN_REC_VEHICLE' and contains(text(),$propertyClass)]]/COLUMN[@NAME = 'OFFENSE_FILE_CLASS']/text() return $a = $offenses, true()))))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-702"
                 as="xs:boolean">
        <xsl:param name="arrestAge" as="xs:string*"/>
        <xsl:param name="arrestDispo" as="xs:string*"/>
        
        <xsl:sequence select="count($arrestAge) &lt;= 1 and boolean($arrestAge) and not(mspfx:valid-range(number($arrestAge), 1, 17)) and not(boolean($arrestDispo))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-925"
                 as="xs:boolean">
        <xsl:param name="properties" as="element()*"/>
        
        <xsl:sequence select="not($completeOffenses = 35002) and exists($properties) and (some $prop in $properties satisfies $prop/msp:PropertyLossCode/text() = 6 and number($prop/msp:PropertyCategoryCode/text()) = 11)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-939"
                 as="xs:boolean">
        <xsl:param name="properties" as="element()*"/>
        
        <xsl:sequence select="not($completeOffenses = 35001) and exists($properties) and (some $prop in $properties satisfies $prop/msp:PropertyLossCode/text() = 6 and number($prop/msp:PropertyCategoryCode/text()) = 10)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-514"
                 as="xs:boolean">
    	<xsl:param name="offenseCode" as="xs:string*"/>
        <xsl:param name="victimType" as="xs:string?"/>
        <xsl:sequence select="boolean(mspfx:victim-function-check-with-supplied-fclass('mspfx:error-514',$offenseCode) and mspfx:checkILVictimTypeForFileClass($offenseCode, $victimType))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-517"
                 as="xs:boolean">
        <xsl:param name="offenseCode" as="xs:string*"/>
        <xsl:param name="victimType" as="xs:string?"/>
        <xsl:param name="victimRole" as="xs:string*"/>
        <xsl:sequence select="boolean($victimType) and (some $x in $offenseCode satisfies boolean(mspfx:victim-function-check-with-supplied-fclass('mspfx:error-517',$x) and mspfx:check-victim-type-valid($victimType, $x)) and count($victimRole) &gt; 0)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-572"
                 as="xs:boolean">
        <xsl:param name="offenseCode" as="xs:string*"/>
        <xsl:param name="victimType" as="xs:string?"/>
        <xsl:param name="victimRole" as="xs:string*"/>
        <xsl:sequence select="boolean($victimType) and (some $x in $offenseCode satisfies boolean(mspfx:victim-function-check-with-supplied-fclass('mspfx:error-572',$x) and mspfx:check-victim-type-valid($victimType, $x)) and count($victimRole) &gt; 0)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-967"
                 as="xs:boolean">
        <xsl:param name="currentOffenseFileClassIN" as="xs:string?"/>
        
        <xsl:sequence select="mspfx:current-ofc-requires-property($currentOffenseFileClassIN) and $propertyCount &lt; 1"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-731"
                 as="xs:boolean">
        <xsl:param name="arrestNumberIN" as="xs:string?"/>
        <xsl:param name="offenderNumberIN" as="xs:string?"/>
        
        <xsl:sequence select="not($arrestNumberIN = $offenderNumberIN)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-1031"
                 as="xs:boolean">
        <xsl:param name="activityCategoryText" as="xs:string?"/>
        
        <xsl:sequence select="boolean($activityCategoryText=('Offense','Incident','Arrest'))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-980"
                 as="xs:boolean">
        <xsl:param name="fileClass" as="xs:string?"/>
        <xsl:param name="completeIndicator" as="xs:boolean?"/>
        
        <xsl:sequence select="$completeIndicator and not(mspfx:prop-class-expected($fileClass)) and not(some $x in $propertyLoss satisfies number($x) = number(9))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-981"
                 as="xs:boolean">
        <xsl:param name="fileClass" as="xs:string?"/>
        <xsl:param name="completeIndicator" as="xs:boolean?"/>
        
        <xsl:sequence select="$completeIndicator and not(mspfx:prop-type-expected($fileClass))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-143"
                 as="xs:boolean">
        <xsl:param name="fileClass" as="xs:string?"/>
        <xsl:param name="activityTypeExists" as="xs:boolean?"/>
        
        <xsl:sequence select="$activityTypeExists and mspfx:activity-type-required($fileClass)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-170"
                 as="xs:boolean">
        <xsl:param name="fileClass" as="xs:string?"/>
        <xsl:param name="activityType" as="xs:string*"/>
        
        <xsl:sequence select="mspfx:correct-activity-types($fileClass,$activityType,'mspfx:error-170')"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-171"
                 as="xs:boolean">
        <xsl:param name="fileClass" as="xs:string?"/>
        <xsl:param name="activityType" as="xs:string*"/>
        
        <xsl:sequence select="mspfx:correct-activity-types($fileClass,$activityType,'mspfx:error-171')"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-176"
                 as="xs:boolean">
        <xsl:param name="fileClass" as="xs:string?"/>
        <xsl:param name="activityType" as="xs:string*"/>
        
        <xsl:sequence select="mspfx:correct-activity-types($fileClass,$activityType,'mspfx:error-176')"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-942"
                 as="xs:boolean">
        <xsl:param name="lossType" as="xs:double?"/>
        <xsl:param name="dateRecoveredExists" as="xs:boolean?"/>
        
        <xsl:sequence select="mspfx:dateRecoveredNotAllowed($lossType) and $dateRecoveredExists"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-969"
                 as="xs:boolean">
        <xsl:param name="lossType" as="xs:string?"/>
        <xsl:param name="propertyClass" as="xs:string?"/>
        <xsl:param name="itemNumber" as="xs:string?"/>
        <xsl:param name="prop"/>
        <xsl:param name="otherProperties"/>
        
        <xsl:choose>
            <xsl:when test="not(some $x in $completeOffenses satisfies(tokenize($micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $x]/../COLUMN[@NAME = 'SCHEMATRON_FUNCTIONS']/text(),',') = 'mspfx:error-969'))">
                
                <xsl:sequence select="$lossType = '5' and not(some $x in $prop satisfies $x/msp:PropertyLossCode/text() = '7' and $x/msp:PropertyCategoryCode/text() = $propertyClass and $x/msp:PropertySequenceNumberText/text() = $itemNumber)"/>
                
            </xsl:when>
            <xsl:when test="every $x in $completeOffenses satisfies(tokenize($micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $x]/../COLUMN[@NAME = 'SCHEMATRON_FUNCTIONS']/text(),',') = 'mspfx:error-969')">
                
                <xsl:sequence select="false()"/>
                
            </xsl:when>
            <xsl:otherwise>
                
                <xsl:sequence select="$lossType = '5' and not(mspfx:other-offense-prop-type-satisfied($otherProperties))"/>
                
            </xsl:otherwise>
        </xsl:choose>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-308"
                 as="xs:boolean">
        <xsl:param name="offenderNumber"/>
        <xsl:param name="offenderRace"/>
        
        <xsl:sequence select="not(mspfx:checkRequiredFields('308','OFFENDER_RACE',$offenderRace/text())) or (empty($offenderRace) and number($offenderNumber) = 0)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-569"
                 as="xs:boolean">
        <xsl:param name="minAgeRangeExists" as="xs:boolean?"/>
        <xsl:param name="maxAgeRangeExists" as="xs:boolean?"/>
        
        <xsl:sequence select="boolean($minAgeRangeExists or $maxAgeRangeExists)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-501"
                 as="xs:boolean">
        <xsl:param name="victimType" as="xs:string?"/>
        <xsl:param name="victimNumber" as="xs:string?"/>
        <xsl:param name="victimRole" as="xs:string*"/>
        
        <xsl:sequence select="not(boolean($victimType)) and boolean($victimNumber) and count($victimRole) &gt; 0"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-559"
                 as="xs:boolean">
        <xsl:param name="vor"/>
        <xsl:param name="offenderAge" as="xs:string?"/>
        <xsl:param name="offenderRace" as="xs:string?"/>
        <xsl:param name="offenderSex" as="xs:string?"/>
        
        <xsl:sequence select="exists($vor/text()) and mspfx:isOffenderUnknown($offenderAge,$offenderRace,$offenderSex) and $vor/text() != '99'"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:warning-w1"
                 as="xs:boolean">
        <xsl:param name="occRepDate" as="xs:string?"/>
        
        <xsl:sequence select="not(number($incidentNumber) = 0) and ((string-length($occRepDate) &lt;= 10) or (string-length($occRepDate) &gt;= 10 and substring($occRepDate,12,2) = '00'))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:county-ori"
                 as="xs:boolean">
        <xsl:param name="oriIN" as="xs:string?"/>
        <xsl:param name="countyIN" as="xs:string?"/>
        
            <xsl:sequence select="boolean($micr_agency_lookup//ROW/COLUMN[@NAME = 'ORI' and text() = $oriIN]/../COLUMN[@NAME = 'REPORTING_JURISDICTION' and text() = 'COUNTY']/../COLUMN[@NAME = 'COUNTY' and number(text()) = number($countyIN)])"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:statewide-ori"
                 as="xs:boolean">
        <xsl:param name="oriIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean($micr_agency_lookup//ROW/COLUMN[@NAME = 'ORI' and text() = $oriIN]/../COLUMN[@NAME = 'REPORTING_JURISDICTION' and text() = 'STATEWIDE'])"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:local-ori"
                 as="xs:boolean">
        <xsl:param name="oriIN" as="xs:string?"/>        
        <xsl:param name="countyIN" as="xs:string?"/>        
        <xsl:param name="cityTwpIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean($micr_agency_lookup//ROW/COLUMN[@NAME = 'ORI' and text() = $oriIN]/../COLUMN[@NAME = 'REPORTING_JURISDICTION' and text() = 'LOCAL'] and (exists($ctxrf_lookup//ROW[COLUMN[@NAME = 'CTXRF_ORI' and text() = $oriIN] and COLUMN[@NAME = 'CTXRF_COUNTY' and text() = $countyIN] and COLUMN[@NAME =  'CTXRF_CITY_TWP' and text() = $cityTwpIN]])))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:valid-ori"
                 as="xs:boolean">
        <xsl:param name="oriIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean($micr_agency_lookup//ROW/COLUMN[@NAME = 'ORI' and text() = $oriIN])"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:valid-range"
                 as="xs:boolean">
        <xsl:param name="numericValueIN" as="xs:double?"/>
        <xsl:param name="lowerRangeIN" as="xs:double?"/>
        <xsl:param name="upperRangeIN" as="xs:double?"/>
        
        <xsl:sequence select="boolean($numericValueIN &gt; $upperRangeIN or $numericValueIN &lt; $lowerRangeIN)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:check-victim-type"
                 as="xs:boolean">
        <xsl:param name="victimTypeIN" as="xs:string?"/>
        <xsl:param name="errorCodeIN" as="xs:string?"/>
        
        <xsl:sequence select="$victimTypeIN = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .=$errorCodeIN]]/COLUMN[@NAME='CODE']"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:all-ofc-prop-class"
                 as="xs:boolean">
        <xsl:param name="currentPropertyClassIN" as="xs:string?"/>
        
        <xsl:sequence select="not(boolean( some $x in $completeOffenses satisfies boolean(true()) = boolean(tokenize(($micr_edits_ofc_prop_class_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $x]/../COLUMN[@NAME = 'PROPERTY_CLASSES']/text()),',') = $currentPropertyClassIN)) or ($zeroPropExitsts and boolean(some $i in $completeOffenses satisfies $micr_edits_zero_prop_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $i])))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:all-ofc-prop-class-req"
                 as="xs:boolean">
        <xsl:param name="currentOffenseClassIN" as="xs:string?"/>
        
        <xsl:sequence select="not(tokenize(($micr_edits_ofc_prop_class_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $currentOffenseClassIN]/../COLUMN[@NAME = 'PROPERTY_CLASSES_REQ']/text()),',') = $propertyClass or ($zeroPropExitsts and $micr_edits_zero_prop_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $currentOffenseClassIN]))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:ofc-prop-class-function-check"
                 as="xs:boolean">
        <xsl:param name="functionIn" as="xs:string?"/>
         
        <xsl:sequence select="boolean(some $x in $completeOffenses satisfies tokenize(($micr_edits_ofc_prop_class_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $x]/../COLUMN[@NAME = 'SCHEMATRON_FUNCTIONS']/text()),',') = $functionIn)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:ofc-prop-class-function-check-with-supplied-fclass"
                 as="xs:boolean">
        <xsl:param name="functionIn" as="xs:string?"/>
        <xsl:param name="fileClassIn" as="xs:string?"/>
         
        <xsl:sequence select="boolean(tokenize(($micr_edits_ofc_prop_class_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $fileClassIn]/../COLUMN[@NAME = 'SCHEMATRON_FUNCTIONS']/text()),',') = $functionIn)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:victim-function-check-with-supplied-fclass"
                 as="xs:boolean">
        <xsl:param name="functionIn" as="xs:string?"/>
        <xsl:param name="fileClassIn" as="xs:string*"/>
         
        <xsl:sequence select="boolean(some $x in $fileClassIn satisfies tokenize(($micr_edits_victim_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $x]/../COLUMN[@NAME = 'SCHEMATRON_FUNCTIONS']/text()),',') = $functionIn)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:arrest-complete-check"
                 as="xs:boolean">
        <xsl:param name="arrestSubjectSid" as="xs:string?"/>
        
        <xsl:param name="offenderID" as="xs:string?"/>
        <xsl:param name="activityID" as="xs:string?"/>
        <xsl:param name="arrestNumber" as="xs:string?"/>
        <xsl:param name="arrestType" as="xs:string?"/>
        <xsl:param name="arrestAge" as="xs:string?"/>
        <xsl:param name="arrestRace" as="xs:string?"/>
        <xsl:param name="arrestSex" as="xs:string?"/>
        <xsl:param name="arrestCharge" as="xs:string?"/>
        <xsl:param name="arrestDate" as="xs:string?"/>
        
        
        <xsl:sequence select="not(string-length($offenderID) &gt; 0             and string-length($activityID) &gt; 0             and string-length($arrestNumber) &gt; 0)"/>
        
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:check-ofc-drug-cat"
                 as="xs:boolean">
        <xsl:param name="currentOffenseClassIN" as="xs:string*"/>
        <xsl:param name="drugCategoryCode" as="xs:string?"/>
        
        <xsl:sequence select="boolean(not(tokenize(($micr_edits_drugs_lookup//ROW/COLUMN[@NAME = 'DRUG_TYPE' and text() = $drugCategoryCode]/../COLUMN[@NAME = 'OFFENSE_FILE_CLASS']/text()),',') = $currentOffenseClassIN))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:check-drug-measure-exists"
                 as="xs:boolean">
        <xsl:param name="drugCategoryCode" as="xs:string?"/>
        <xsl:param name="drugMeasurement" as="xs:string?"/>
        <xsl:param name="lossType" as="xs:double?"/>
        
        <xsl:sequence select="boolean(not(($micr_edits_drugs_lookup//ROW/COLUMN[@NAME = 'DRUG_TYPE' and text() = $drugCategoryCode]/../COLUMN[@NAME = 'LOSS' and text() = $lossType]/../COLUMN[@NAME = 'DRUG_MEASURE']/text()) != ' '))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:check-drug-quantity-exists"
                 as="xs:boolean">
        <xsl:param name="drugCategoryCode" as="xs:string?"/>
        <xsl:param name="drugQuantity" as="xs:string?"/>
        <xsl:param name="lossType" as="xs:double?"/>
        
        <xsl:choose>
            <xsl:when test="boolean(tokenize($micr_edits_zero_prop_lookup//ROW/COLUMN[@NAME = 'DRUG_QTY_GT_ZERO' and text() = 'N']/../COLUMN[@NAME = 'LOSS_TYPES']/text(),',') = string($lossType))">
                <xsl:sequence select="boolean(not(string-length($drugQuantity) = 0 or number($drugQuantity) = 0))"/>
                
            </xsl:when>
            <xsl:otherwise>
                <xsl:sequence select="boolean(not(number($drugQuantity) &gt; 0))"/>
                
            </xsl:otherwise>
        </xsl:choose>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:offender-number-0-exists"
                 as="xs:boolean">
        <xsl:sequence select="boolean(some $x in $offenderNumbers satisfies $x = 0)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:victim-type-i-l"
                 as="xs:boolean">
        <xsl:param name="victimType" as="xs:string?"/>
        <xsl:sequence select="boolean($victimType = ('I','L'))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:no-offender-number-exists"
                 as="xs:boolean">
        
        <xsl:sequence select="boolean(count(distinct-values($offenderNumbers)) = 0)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:check-drug-prop-class"
                 as="xs:boolean">
        <xsl:param name="drugCategoryCode" as="xs:string?"/>
        <xsl:param name="propClassIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean(not(empty($propClassIN)) and not(tokenize(($micr_edits_drugs_lookup//ROW/COLUMN[@NAME = 'DRUG_TYPE' and text() = $drugCategoryCode]/../COLUMN[@NAME = 'PROPERTY_CLASS']/text()),',') = $propClassIN))"/>        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:ofcGroupAexist"
                 as="xs:boolean">
        
        <xsl:sequence select="boolean(some $x in $offenses  satisfies $x = $filec_lookup//ROW[COLUMN[@NAME='OFFENSE_AB_NDICATOR' and .= 'A']]/COLUMN[@NAME='FILEC_OFFENSE_CO'])"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:arresChargeGroup"
                 as="xs:string*">
        <xsl:param name="arrestCharge" as="xs:string?"/>
        <xsl:sequence select="$arrcd_lookup//ROW[COLUMN[@NAME='ARRCD_ARREST_CO' and .= $arrestCharge]]/COLUMN[@NAME='ARRCD_ARRCD_TYPE']"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:drugType77NumDrugsCheck"
                 as="xs:boolean">
        <xsl:param name="drugCategoryCode" as="xs:string*"/>
        <xsl:param name="drugCount" as="xs:integer?"/>
        
        <xsl:sequence select="($micr_edits_drugs_lookup//ROW/COLUMN[@NAME = 'DRUG_TYPE' and text() = $drugCategoryCode]/../COLUMN[@NAME = 'ADDITIONAL_DRUG']/text()) &gt; 0 and ($micr_edits_drugs_lookup//ROW/COLUMN[@NAME = 'DRUG_TYPE' and text() = $drugCategoryCode]/../COLUMN[@NAME = 'ADDITIONAL_DRUG']/text()) &gt; ($drugCount - 1)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:checkDrugExists"
                 as="xs:boolean">
        <xsl:param name="offenses" as="xs:string*"/>
        <xsl:param name="drugType" as="xs:string?"/>
        <xsl:param name="lossType" as="xs:string?"/>
        <xsl:param name="drugSequence" as="xs:string?"/>
        <xsl:param name="otherDrugCnt" as="xs:integer?"/>
        <xsl:param name="otherFileClassCnt" as="xs:integer?"/>
        
        <xsl:sequence select="($offenses = '35001' and $drugSequence = '0' and $lossType = '0') and (($drugType != '99' or not(exists($drugType))) and not($otherDrugCnt &gt; 0 and $otherFileClassCnt &gt; 0))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:checkDrugCat99"
                 as="xs:boolean">
        <xsl:param name="countDrugCat99" as="xs:integer?"/>
        
        <xsl:sequence select="$countDrugCat99 &gt; 1"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:checkVorExists"
                 as="xs:boolean">
        <xsl:param name="vor" as="xs:boolean?"/>
        <xsl:param name="offenseCode" as="xs:string*"/>
        <xsl:param name="victimType" as="xs:string?"/>
        <xsl:param name="offenderNumbers" as="xs:string*"/>
        <xsl:param name="separator" as="xs:string?"/>
        
        <xsl:sequence select="(not($vor) and (tokenize(string-join($micr_edits_victim_lookup//ROW/COLUMN[@NAME='OFFENSE_FILE_CLASS' and text() = $offenseCode]/../COLUMN[@NAME = 'VOR_REQ_VICTIM_TYPES']/text(),$separator),',')) = $victimType and (some $n in $offenderNumbers satisfies (number($n) &gt; 0)))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:checkILVictimTypeForFileClass"
                 as="xs:boolean">
	    <xsl:param name="offenseCode" as="xs:string*"/>
	    <xsl:param name="victimType" as="xs:string?"/>
	    
	    <xsl:sequence select="($micr_edits_victim_lookup//ROW/COLUMN[@NAME='OFFENSE_FILE_CLASS' and text() = $offenseCode]/../COLUMN[@NAME = 'VALID_VICTIM_TYPES']/text() = 'I,L') and not(mspfx:victim-type-i-l($victimType))"/>
	  </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:offense-victimCircumstance"
                 as="xs:boolean">
        <xsl:param name="offenseCode" as="xs:string?"/>
        <xsl:param name="victimCircumstance" as="xs:string*"/>
        <xsl:param name="vicConnectedOffenseCodes" as="xs:string*"/>
        
        <xsl:sequence select="(tokenize($micr_edits_victim_circ_lookup//ROW/COLUMN[@NAME='OFFENSE_FILE_CLASS' and text() = $offenseCode]/../COLUMN[@NAME = 'ALLOWED_VIC_CIRC_CODES']/text(),',')) = $victimCircumstance and not(some $t in $vicConnectedOffenseCodes satisfies $micr_edits_victim_circ_lookup//ROW/COLUMN[@NAME='OFFENSE_FILE_CLASS' and text() = $offenseCode]/../COLUMN[@NAME = 'OVERRIDE_FILE_CLASS' and text() = $t])"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:offense-victimCircumstance-edit"
                 as="xs:boolean">
        <xsl:param name="offenseCode" as="xs:string?"/>
        <xsl:param name="schematronFunction" as="xs:string?"/>
        
        <xsl:sequence select="(some $x in tokenize($micr_edits_victim_circ_lookup//ROW/COLUMN[@NAME='OFFENSE_FILE_CLASS' and text() = $offenseCode]/../COLUMN[@NAME = 'SCHEMATRON_FUNCTION']/text(),',' ) satisfies $x = $schematronFunction)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:check-arrestChargeCode"
                 as="xs:boolean">
        <xsl:param name="arrestCharge" as="xs:string?"/>
        <xsl:param name="offenderArrestSubjectCount" as="xs:double?"/>
        
        <xsl:sequence select="boolean($arrestCharge) and not ($arrcd_lookup//ROW/COLUMN[@NAME='ARRCD_ARREST_CO'] = $arrestCharge) and $offenderArrestSubjectCount &gt; 0"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:check-biasCode"
                 as="xs:boolean">
        <xsl:param name="biasCode" as="xs:string?"/>
        
        <xsl:sequence select="distinct-values($bias_lookup//ROW/COLUMN[@NAME='BIAS_CODE']/text()) = $biasCode"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:victim-law-enforcement"
                 as="xs:boolean">
        <xsl:param name="victimType" as="xs:string?"/>
        
        <xsl:sequence select="boolean($victimType = 'L')"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:string-check"
                 as="xs:boolean">
        <xsl:param name="inputString" as="xs:string*"/>
        <xsl:param name="expectedString" as="xs:string?"/>
        
        <xsl:sequence select="boolean($inputString = $expectedString)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:ofc-property-lkp"
                 as="xs:boolean">
        <xsl:param name="propertyRequired" as="xs:string?"/>
        
        <xsl:sequence select="boolean(every $offenseFileClass in $offenses satisfies ($filec_lookup//ROW/COLUMN[@NAME = 'PROPERTY_REQUIRED' and text() = $propertyRequired]/../COLUMN[@NAME = 'FILEC_OFFENSE_CO' and text() = $offenseFileClass]))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:ofc-property-lkp-count"
                 as="xs:integer">
        <xsl:param name="propertyRequired" as="xs:string?"/>
        
        <xsl:sequence select="count($filec_lookup//ROW/COLUMN[@NAME = 'PROPERTY_REQUIRED' and text() = $propertyRequired]/../COLUMN[@NAME = 'FILEC_OFFENSE_CO' and text() = $offenseFileClasses])"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:check-victim-type-valid"
                 as="xs:boolean">
        <xsl:param name="victimType" as="xs:string?"/>
        <xsl:param name="offenseCode" as="xs:string*"/>
        
        <xsl:sequence select="boolean(some $y in $offenseCode satisfies some $x in tokenize($micr_edits_victim_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $y]/../COLUMN[@NAME = 'VALID_VICTIM_TYPES']/text(),',') satisfies $x != $victimType)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:current-ofc-requires-property"
                 as="xs:boolean">
        <xsl:param name="offenseFileClassIN" as="xs:string?"/>
        
        <xsl:sequence select="boolean($micr_edits_ofc_prop_class_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $offenseFileClassIN])"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:prop-class-expected"
                 as="xs:boolean">
        <xsl:param name="fileClass" as="xs:string?"/>
        
        <xsl:sequence select="not($micr_edits_ofc_prop_class_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $fileClass])or(some $x in $propertyClass satisfies tokenize($micr_edits_ofc_prop_class_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $fileClass]/../COLUMN[@NAME = 'PROPERTY_CLASSES']/text(),',') = $x) or ($zeroPropExitsts and $micr_edits_zero_prop_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $fileClass])"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:prop-type-expected"
                 as="xs:boolean">
        <xsl:param name="fileClass" as="xs:string?"/>
        
        <xsl:sequence select="not($micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $fileClass])or(some $x in $propertyLoss satisfies tokenize($micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $fileClass]/../COLUMN[@NAME = 'PROPERTY_LOSS_TYPES']/text(),',') = $x) or ($zeroPropExitsts and $micr_edits_zero_prop_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $fileClass])"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:ofc-prop-loss-function-check"
                 as="xs:boolean">
        <xsl:param name="functionIn" as="xs:string?"/>
         
        <xsl:sequence select="boolean(some $x in $completeOffenses satisfies tokenize(($micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $x]/../COLUMN[@NAME = 'SCHEMATRON_FUNCTIONS']/text()),',') = $functionIn)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:prop-loss-error"
                 as="xs:boolean">
        <xsl:param name="currentLossType" as="xs:string?"/>
        <xsl:param name="functionIn" as="xs:string?"/>
         
        <xsl:sequence select="not(every $o in ($micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'SCHEMATRON_FUNCTIONS' and tokenize(text(),',')=$functionIn]/../COLUMN[@NAME = 'OFFENSE_FILE_CLASS']/text()) satisfies tokenize(($micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $o]/../COLUMN[@NAME = 'PROPERTY_LOSS_TYPES']/text()),',') = $currentLossType)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:prop-loss-ofcs"
                 as="xs:boolean">
        <xsl:param name="currentLossType" as="xs:string?"/>
         
        <xsl:sequence select="not(some $o in ($completeOffenses) satisfies tokenize(($micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $o]/../COLUMN[@NAME = 'PROPERTY_LOSS_TYPES']/text()),',') = $currentLossType)"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:attempted-property-offense-with-zero-property-exists"
                 as="xs:boolean">
        
        <xsl:sequence select="(some $o in ($attemptOffenses) satisfies mspfx:current-ofc-requires-property($o)) and $zeroPropExitsts and (some $o in ($completeOffenses) satisfies mspfx:current-ofc-requires-property($o)) and $nonZeroPropExists"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:activity-type-required"
                 as="xs:boolean">
        <xsl:param name="fileClass" as="xs:string?"/>
        
        <xsl:sequence select="boolean($activityTypeEdits_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $fileClass]/../COLUMN[@NAME = 'ACTIVITY_TYPE_REQUIRED' and text() = 'Y'])"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:correct-activity-types"
                 as="xs:boolean">
        <xsl:param name="fileClass" as="xs:string?"/>
        <xsl:param name="activityType" as="xs:string*"/>
        <xsl:param name="function" as="xs:string?"/>
        
        <xsl:sequence select="tokenize($activityTypeEdits_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $fileClass]/../COLUMN[@NAME = 'SCHEMATRON_FUNCTIONS']/text(),',') = $function and  not(every $x in $activityType satisfies (tokenize(($activityTypeEdits_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $fileClass]/../COLUMN[@NAME = 'ACTIVITY_TYPE']/text()),',') = $x))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:dateRecoveredNotAllowed"
                 as="xs:boolean">
        <xsl:param name="lossType" as="xs:double?"/>
        
        <xsl:sequence select="boolean($micr_edits_req_prop_loss_lookup//ROW/COLUMN[@NAME = 'PROPERTY_LOSS_TYPE' and text() = $lossType]/../COLUMN[@NAME = 'TYPE' and text() = 'NOT_ALLOWED']/../COLUMN[@NAME = 'FIELD' and text() = 'DateRecovered'])"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:itemNumberRequired"
                 as="xs:boolean">
        <xsl:param name="lossType" as="xs:double?"/>
        
        <xsl:sequence select="boolean($micr_edits_req_prop_loss_lookup//ROW/COLUMN[@NAME = 'PROPERTY_LOSS_TYPE' and text() = $lossType]/../COLUMN[@NAME = 'TYPE' and text() = 'REQUIRED']/../COLUMN[@NAME = 'FIELD' and text() = 'PropertySequenceNumberText'])"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:other-offense-prop-type-satisfied"
                 as="xs:boolean">
        
        <xsl:param name="otherProperties"/>
        
        <xsl:sequence select="every $offense in $completeOffenses[not(. = $micr_edits_cofc_prop_loss_type_lookup//ROW[COLUMN[@NAME = 'SCHEMATRON_FUNCTIONS' and tokenize(.,',')= 'mspfx:error-969' ]]/COLUMN[@NAME = 'OFFENSE_FILE_CLASS'])] satisfies (($micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $offense])             and (some $x in $otherProperties satisfies (tokenize($micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $offense]/../COLUMN[@NAME = 'PROPERTY_LOSS_TYPES']/text(),',') = $x/msp:PropertyLossCode/text() and (tokenize($micr_edits_ofc_prop_class_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $offense]/../COLUMN[@NAME = 'PROPERTY_CLASSES_REQ']/text(),',') = $x/msp:PropertyCategoryCode/text() or (tokenize($micr_edits_ofc_prop_class_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $offense]/../COLUMN[@NAME = 'PROPERTY_CLASSES_REQ']/text(),',') = ' ' and tokenize($micr_edits_ofc_prop_class_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $offense]/../COLUMN[@NAME = 'PROPERTY_CLASSES']/text(),',') = $x/msp:PropertyCategoryCode/text() and $micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $offense]/../COLUMN[@NAME = 'PROPERTY_LOSS_TYPE_REQUIRED']/text() = 'Y')))              and not(count($otherProperties/msp:PropertyLossCode/text()[not(.= '5')]) = 0))              or not($micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $offense])              or ($zeroPropExitsts and $micr_edits_zero_prop_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $offense]))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:checkRequiredFields"
                 as="xs:boolean">
        <xsl:param name="errorNumber" as="xs:string?"/>
        <xsl:param name="field" as="xs:string?"/>
        <xsl:param name="input" as="xs:string?"/>
        
        <xsl:choose>
            <xsl:when test="$field = 'OFFENDER_RACE'">
                <xsl:sequence select="boolean($micr_edits_offender_req_lookup//ROW/COLUMN[@NAME = 'ERROR_NUMBER' and text() = $errorNumber]/../COLUMN[@NAME = 'OFFENDER_RACE' and text() = 'Y'] and string-length($input) &lt; 1)"/>
            </xsl:when>
        </xsl:choose>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:isOffenderUnknown"
                 as="xs:boolean">
        <xsl:param name="offenderAge" as="xs:string?"/>
        <xsl:param name="offenderRace" as="xs:string?"/>
        <xsl:param name="offenderSex" as="xs:string?"/>
        
        <xsl:sequence select="number($offenderAge) = 0 and $offenderRace = 'U' and $offenderSex = 'U'"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:all-ofc-prop-class-type"
                 as="xs:boolean">
        <xsl:param name="currentPropertyClassIN" as="xs:string?"/>
        <xsl:param name="currentPropertyTypeIN" as="xs:string?"/>
        
        <xsl:sequence select="not(boolean( some $x in $completeOffenses satisfies boolean(true()) = boolean(tokenize(($micr_edits_ofc_prop_class_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $x]/../COLUMN[@NAME = 'PROPERTY_CLASSES']/text()),',') = $currentPropertyClassIN) and tokenize($micr_edits_cofc_prop_loss_type_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $x]/../COLUMN[@NAME = 'PROPERTY_LOSS_TYPES']/text(),',') = $currentPropertyTypeIN) or ($zeroPropExitsts and boolean(some $i in $completeOffenses satisfies $micr_edits_zero_prop_lookup//ROW/COLUMN[@NAME = 'OFFENSE_FILE_CLASS' and text() = $i])))"/>
        
    </xsl:function>

   <!--DEFAULT RULES-->


<!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
<!--This mode can be used to generate prefixed XPath for humans-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
<!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
<xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
<xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters--><xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
<xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl" title="" schemaVersion="">
         <xsl:attribute name="phase">delete-edits-only</xsl:attribute>
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="http://purl.oclc.org/dsdl/schematron" prefix="iso"/>
         <svrl:ns-prefix-in-attribute-values uri="http://niem.gov/niem/niem-core/2.0" prefix="nc"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/1999/XSL/Transform" prefix="xsl"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema" prefix="xsd"/>
         <svrl:ns-prefix-in-attribute-values uri="http://usdoj.gov/leisp/lexs/3.1" prefix="lexs"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema" prefix="xs"/>
         <svrl:ns-prefix-in-attribute-values uri="http://usdoj.gov/leisp/lexs/digest/3.1" prefix="lexsdigest"/>
         <svrl:ns-prefix-in-attribute-values uri="http://fbi.gov/cjis/N-DEx/IncidentArrest/2.1" prefix="ndexia"/>
         <svrl:ns-prefix-in-attribute-values uri="http://usdoj.gov/leisp/lexs/library/3.1" prefix="lexslib"/>
         <svrl:ns-prefix-in-attribute-values uri="http://niem.gov/niem/structures/2.0" prefix="s"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2005/xpath-functions" prefix="fn"/>
         <svrl:ns-prefix-in-attribute-values uri="http://usdoj.gov/leisp/lexs/publishdiscover/3.1" prefix="lexspd"/>
         <svrl:ns-prefix-in-attribute-values uri="http://niem.gov/niem/domains/jxdm/4.0" prefix="j"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.michigan.gov/msp/IncidentReporting/exchange/1.0"
                                             prefix="mspRoot"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.michigan.gov/msp/IncidentReporting/extensions/1.0"
                                             prefix="msp"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.michigan.gov/msp/IncidentReporting" prefix="mspfx"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">incident-details</xsl:attribute>
            <xsl:attribute name="name">incident-details</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M207"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">admin-data-constraints</xsl:attribute>
            <xsl:attribute name="name">admin-data-constraints</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M209"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->
<xsl:param name="fbi_codes" select="document('./schema/xsd/niem/fbi/2.0/fbi.xsd')"/>
   <xsl:param name="msp_codes" select="document('./schema/xsd/msp/MSP_Codes.xsd')"/>
   <xsl:param name="ori_codes"
              select="document('./schema/xsd/msp/MICR_ORI_Codes.xsd')"/>
   <xsl:param name="ndexia_codes"
              select="document('./schema/xsd/ndexia/ndexia-codes/2.1/ndexia-codes.xsd')"/>
   <xsl:param name="ctxrf_lookup" select="document('./tables/CTXRF.xml')"/>
   <xsl:param name="orict_lookup" select="document('./tables/ORICT.xml')"/>
   <xsl:param name="filec_lookup" select="document('./tables/FILEC.xml')"/>
   <xsl:param name="val_lookup"
              select="document('./tables/SCHEMATRON_VALIDATION_LOOKUP.xml')"/>
   <xsl:param name="arrcd_lookup" select="document('./tables/ARRCD.xml')"/>
   <xsl:param name="ethinicity_lookup" select="document('./tables/ETHNICITY.xml')"/>
   <xsl:param name="residence_lookup" select="document('./tables/RESIDENCE.xml')"/>
   <xsl:param name="weapon_lookup" select="document('./tables/WEAPON.xml')"/>
   <xsl:param name="offenseactivity_lookup"
              select="document('./tables/OFFENSEACTIVITY.xml')"/>
   <xsl:param name="bias_lookup" select="document('./tables/BIAS.xml')"/>
   <xsl:param name="location_lookup" select="document('./tables/LOCATION.xml')"/>
   <xsl:param name="propertyloss_lookup"
              select="document('./tables/PROPERTYLOSS.xml')"/>
   <xsl:param name="propertyclass_lookup"
              select="document('./tables/PROPERTYCLASS.xml')"/>
   <xsl:param name="drug_lookup" select="document('./tables/DRUG.xml')"/>
   <xsl:param name="vor_lookup" select="document('./tables/VOR.xml')"/>
   <xsl:param name="injury_lookup" select="document('./tables/INJURY.xml')"/>
   <xsl:param name="msp_statewide_lookup"
              select="document('./tables/MICR_ORI_STATEWIDE.xml')"/>
   <xsl:param name="micr_agency_lookup" select="document('./tables/MICR_AGENCY.xml')"/>
   <xsl:param name="activityTypeEdits_lookup"
              select="document('./tables/MICR_ACTIVITY_TYPE_EDITS.xml')"/>
   <xsl:param name="micr_edits_lookup"
              select="document('./tables/MICR_EDITS_LKP.xml')"/>
   <xsl:param name="micr_edits_cofc_prop_loss_lookup"
              select="document('./tables/MICR_EDITS_COFC_PROP_LOSS_LKP.xml')"/>
   <xsl:param name="micr_edits_req_prop_loss_lookup"
              select="document('./tables/MICR_EDITS_REQ_PROP_LOSS_LKP.xml')"/>
   <xsl:param name="micr_edits_ofc_prop_class_lookup"
              select="document('./tables/MICR_EDITS_OFC_PROP_CLASS_LKP.xml')"/>
   <xsl:param name="micr_edits_drugs_lookup"
              select="document('./tables/MICR_EDITS_DRUGS_LKP.xml')"/>
   <xsl:param name="micr_edits_victim_lookup"
              select="document('./tables/MICR_EDITS_VICTIM_LKP.xml')"/>
   <xsl:param name="micr_edits_victim_circ_lookup"
              select="document('./tables/MICR_EDITS_VICTIM_CIRC_LKP.xml')"/>
   <xsl:param name="micr_edits_cofc_prop_loss_type_lookup"
              select="document('./tables/MICR_EDITS_COFC_PROP_LOSS_TYPE_LKP.xml')"/>
   <xsl:param name="micr_edits_zero_prop_lookup"
              select="document('./tables/MICR_EDITS_ZERO_PROP_LKP.xml')"/>
   <xsl:param name="micr_edits_offender_req_lookup"
              select="document('./tables/MICR_EDITS_OFFENDER_REQ_LKP.xml')"/>
   <xsl:param name="action"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:ActionCode"/>
   <xsl:param name="arrestExists"
              select="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:ArrestSubject/nc:RoleOfPersonReference)"/>
   <xsl:param name="assistOriId"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/nc:Organization[@s:id = //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:AssistingOrganization/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
   <xsl:param name="incidentDate"
              select="substring(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/*[text()] | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/*[text()and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/*[text()])] ,1,10)"/>
   <xsl:param name="incidentDateTime"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text() | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime[text() and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text())]"/>
   <xsl:param name="isActionOR" select="$action = 'O' or $action = 'R'"/>
   <xsl:param name="isExClear"
              select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident/j:IncidentAugmentation/j:IncidentExceptionalClearanceCode/text())"/>
   <xsl:param name="occurDate"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate[nc:DateTime | nc:Date]/text()"/>
   <xsl:param name="offenderExists"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Subject/nc:RoleOfOrganizationReference"/>
   <xsl:param name="offenderExist"
              select="boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Subject/nc:RoleOfOrganizationReference)"/>
   <xsl:param name="offenseExists"
              select="exists(//lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText = 'Offense'])"/>
   <xsl:param name="offenseCount"
              select="count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Offense'])"/>
   <xsl:param name="ori"
              select="//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI"/>
   <xsl:param name="victcomimCount"
              select="count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Victim)"/>
   <xsl:param name="victimExist"
              select="boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Victim)"/>
   <xsl:param name="victimExists"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim/nc:RoleOfPersonReference or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Victim/nc:RoleOfOrganizationReference"/>
   <xsl:param name="propertyClass"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyCategoryCode"/>
   <xsl:param name="propertyExist"
              select="boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug)"/>
   <xsl:param name="propertyExists"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property/nc:RoleOfItemReference or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Property/nc:RoleOfItemReference"/>
   <xsl:param name="propertyLoss"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyLossCode"/>
   <xsl:param name="offenderCount"
              select="count((//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference, //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Subject/nc:RoleOfOrganizationReference))"/>
   <xsl:param name="offenders"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference"/>
   <xsl:param name="arrestClearanceTrueCount"
              select="count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation[ndexia:ArresteeClearanceIndicator=true()])"/>
   <xsl:param name="offenseFileClasses"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode"/>
   <xsl:param name="propertyCount"
              select="count((//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property, //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug))"/>
   <xsl:param name="zeroPropertyCount"
              select="count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:PropertySequenceNumberText=0 and msp:PropertyLossCode = 0])"/>
   <xsl:param name="zeroDrugCount"
              select="count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug[msp:SuspectedDrugCategoryCode = 99 and msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref[../../../msp:PropertySequenceNumberText = 0 and ../../../msp:PropertyLossCode = 0]])"/>
   <xsl:param name="offenses"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode"/>
   <xsl:param name="completeOffenses"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref[../../../ndexia:OffenseCompletedIndicator = true()]]"/>
   <xsl:param name="attemptOffenses"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref[../../../ndexia:OffenseCompletedIndicator = false()]]"/>
   <xsl:param name="completeReqProp"
              select="$completeOffenses = ($filec_lookup//ROW[COLUMN/@NAME = 'PROP_REQUIRED' and COLUMN/text() = 'Y']/COLUMN[@NAME = 'FILEC_OFFENSE_CO']/text())"/>
   <xsl:param name="attemptReqProp"
              select="$attemptOffenses = ($val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 162]/COLUMN[@NAME = 'CODE']/text(), 39000 to 39009)"/>
   <xsl:param name="lossTypeList"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyLossCode/text()"/>
   <xsl:param name="duplicateOffender"
              select="count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText) != count(distinct-values(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText))"/>
   <xsl:param name="incidentNumber"
              select="//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID/text()"/>
   <xsl:param name="isZeroRec"
              select="$incidentNumber castable as xs:integer and number($incidentNumber) = 0"/>
   <xsl:param name="incidentComplete"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident/msp:IncidentCompleteIndicator"/>
   <xsl:param name="zeroPropExitsts"
              select="some $prop in //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = 0 and $prop/msp:PropertySequenceNumberText/number(text()) = 0"/>
   <xsl:param name="nonZeroPropExists"
              select="some $prop in //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) != 0 or $prop/msp:PropertySequenceNumberText/number(text()) != 0"/>
   <xsl:param name="offenderNumbers"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText/number(text())"/>
   <xsl:param name="offenderNumbersNot0"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText[number(text()) != 0]"/>

   <!--PATTERN incident-details-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage" priority="1000" mode="M207">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage"/>
      <xsl:variable name="incidentNumber"
                    select="./lexs:Digest/lexsdigest:EntityActivity/nc:Activity/nc:ActivityIdentification/nc:IdentificationID"/>

		    <!--REPORT info-->
<xsl:if test="$ori">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$ori">
            <xsl:attribute name="id">ori</xsl:attribute>
            <xsl:attribute name="role">info</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="$ori"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT info-->
<xsl:if test="exists($incidentNumber/text()) and $incidentNumber/text() castable as xs:integer">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($incidentNumber/text()) and $incidentNumber/text() castable as xs:integer">
            <xsl:attribute name="id">incident-number</xsl:attribute>
            <xsl:attribute name="role">info</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="format-number($incidentNumber,'0000000000')"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT info-->
<xsl:if test="$action">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$action">
            <xsl:attribute name="id">action</xsl:attribute>
            <xsl:attribute name="role">info</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="$action"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT info-->
<xsl:if test="$incidentDate">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$incidentDate">
            <xsl:attribute name="id">orig-year</xsl:attribute>
            <xsl:attribute name="role">info</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="format-date(xs:date($incidentDate),'[Y0001]')"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M207"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M207"/>
   <xsl:template match="@*|node()" priority="-2" mode="M207">
      <xsl:apply-templates select="*" mode="M207"/>
   </xsl:template>

   <!--PATTERN admin-data-constraints-->


	<!--RULE -->
<xsl:template match="//msp:ActionCode" priority="1008" mode="M209">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl" context="//msp:ActionCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$msp_codes//xsd:simpleType[@name='ActionCodeSimpleType']//xsd:enumeration/@value = ."/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$msp_codes//xsd:simpleType[@name='ActionCodeSimpleType']//xsd:enumeration/@value = .">
               <xsl:attribute name="id">175</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>175: ACTION MUST BE O/R/D</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="$isZeroRec and not(text() = 'O') and $isActionOR">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$isZeroRec and not(text() = 'O') and $isActionOR">
            <xsl:attribute name="id">117</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>117: ACTION MUST BE O</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M209"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage" priority="1007" mode="M209">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="mspfx:valid-ori($ori)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="mspfx:valid-ori($ori)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>101: ORI NOT VALID
		</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M209"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID"
                 priority="1006"
                 mode="M209">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="text() castable as xs:integer and number(text()) &gt;= 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="text() castable as xs:integer and number(text()) &gt;= 0">
               <xsl:attribute name="id">177_1</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>177: INCIDENT NUMBER MUST BE NUMERIC</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(text()) &lt;= 10"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string-length(text()) &lt;= 10">
               <xsl:attribute name="id">177_2</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>177:
			INCIDENT NUMBER MUST 10 CHARACTER OR LESS</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(.) = 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(.) = 1">
               <xsl:attribute name="id">177_3</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>177: SUBMISSION
			SHOULD ONLY CONTAIN ONE INCIDENT NUMBER</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(text())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(text())">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>111: INCIDENT NUMBER
			REQUIRED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M209"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//msp:LocationCountyCode" priority="1005" mode="M209">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//msp:LocationCountyCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not($isActionOR) or empty(.) or distinct-values($ctxrf_lookup//ROW/COLUMN[@NAME = 'CTXRF_COUNTY']/text()) = number(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($isActionOR) or empty(.) or distinct-values($ctxrf_lookup//ROW/COLUMN[@NAME = 'CTXRF_COUNTY']/text()) = number(.)">
               <xsl:attribute name="id">110</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>110: INVALID COUNTY NUMBER</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M209"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']"
                 priority="1004"
                 mode="M209">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="empty($incidentDateTime) or number(substring($incidentDateTime,12,2)) = (0 to 23,99)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($incidentDateTime) or number(substring($incidentDateTime,12,2)) = (0 to 23,99)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>138: HOUR-OCC MUST BE 00 TO 23 OR 99</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$incidentDate castable as xs:date"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$incidentDate castable as xs:date">
               <xsl:attribute name="id">113</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>113: INCIDENT DATE IS NOT VALID</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text()) &gt; 0 and $isZeroRec and $isActionOR">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text()) &gt; 0 and $isZeroRec and $isActionOR">
            <xsl:attribute name="id">121</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>121: REPORT DATE INDICATOR MUST BE R WITH ZERO RECORD
			ENTRY</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not((string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text()) &gt; 0 or string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:Date/text()) &gt; 0) or ( string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime/text()) &gt; 0 or string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:Date/text()) &gt; 0)) and $isActionOR">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not((string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text()) &gt; 0 or string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:Date/text()) &gt; 0) or ( string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime/text()) &gt; 0 or string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:Date/text()) &gt; 0)) and $isActionOR">
            <xsl:attribute name="id">122</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>122: REPORT DATE INDICATOR MUST BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$isActionOR and $isZeroRec and $incidentDate castable as xs:date and not(day-from-date(xs:date($incidentDate)) = 1)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$isActionOR and $isZeroRec and $incidentDate castable as xs:date and not(day-from-date(xs:date($incidentDate)) = 1)">
            <xsl:attribute name="id">120</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>120: DAY IN INCIDENT MUST BE 01</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate[nc:DateTime | nc:Date]/*[1]/text() | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate[nc:DateTime | nc:Date]/*[1][text() and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate[nc:DateTime | nc:Date]/*[1]/text())])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate[nc:DateTime | nc:Date]/*[1]/text() | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate[nc:DateTime | nc:Date]/*[1][text() and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate[nc:DateTime | nc:Date]/*[1]/text())])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>134: INCIDENT DATE IS REQUIRED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M209"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//j:IncidentExceptionalClearanceCode"
                 priority="1003"
                 mode="M209">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//j:IncidentExceptionalClearanceCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not($isActionOR) or empty(text()) or $fbi_codes//xsd:simpleType[@name='IncidentExceptionalClearanceCodeSimpleType']//xsd:enumeration/@value = ."/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($isActionOR) or empty(text()) or $fbi_codes//xsd:simpleType[@name='IncidentExceptionalClearanceCodeSimpleType']//xsd:enumeration/@value = .">
               <xsl:attribute name="id">114</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>114: EXCEPTIONAL CLEARANCE MUST BE 10/11/12/13/14
		</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M209"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"
                 priority="1002"
                 mode="M209">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"/>

		    <!--REPORT error-->
<xsl:if test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID) and not(some $x in //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimCategoryCode satisfies ($x = 'L'))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID) and not(some $x in //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimCategoryCode satisfies ($x = 'L'))">
            <xsl:attribute name="id">112</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>112: ASSIST ORI IS NOT A VALID FIELD</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M209"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"
                 priority="1001"
                 mode="M209">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime | nc:Date or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/nc:DateTime | nc:Date) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime | nc:Date or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/nc:DateTime | nc:Date)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, DATE OF OCCURRENCE/REPORT IS
			MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(exists(//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI/text()))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(exists(//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, ORI IS MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(exists(//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID/text()))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(exists(//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, INCIDENT NUMBER IS MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/*[text()]) or exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/*[text()]))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/*[text()]) or exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/*[text()]))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, CANNOT DETERMINE ORIGINAL YEAR FROM
			ROPORT DATE OR ACTIVITY DATE</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(not($isActionOR) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress/msp:LocationCountyCode/text())) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(not($isActionOR) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress/msp:LocationCountyCode/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, COUNTY CODE IS MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(not($isActionOR) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress/msp:LocationCityTownshipCode/text()))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(not($isActionOR) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress/msp:LocationCityTownshipCode/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, CITY/TOWNSHIP CODE IS MISSING
		</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident/msp:IncidentCompleteIndicator)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident/msp:IncidentCompleteIndicator)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, INCIDENT COMPLETE INDICATOR MISSING
		</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident'])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, INCIDENT ENTITY ACTIVITY MISSING
		</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, NDEXIA:INCIDENT MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/nc:DateTime  or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/nc:DateTime or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, MISSING HOUR OCCURRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M209"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText"
                 priority="1000"
                 mode="M209">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="mspfx:error-1031(./text())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="mspfx:error-1031(./text())">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="mspfx:error-message('1031')"/>
                  <xsl:text/>
		             </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M209"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M209"/>
   <xsl:template match="@*|node()" priority="-2" mode="M209">
      <xsl:apply-templates select="*" mode="M209"/>
   </xsl:template>
</xsl:stylesheet>
